@@ -429,10 +429,10 @@ class RuleStructure(object):
       self.SortUnnestings()
       for element, the_list in self.unnestings:
         tables.append(
-            'UNNEST(%s) as %s' % (ql.ConvertToSql(the_list),
-                                  ql.ConvertToSql(element)))
+            subquery_encoder.execution.dialect.UnnestPhrase().format(
+                ql.ConvertToSql(the_list), ql.ConvertToSql(element)))
       if not tables:
-        tables.append('UNNEST(ARRAY[\'UNUSED\']) as unused_unnest')
+        tables.append('(SELECT "singleton" as s) as unused_singleton')
       from_str = ', '.join(tables)
       # Indent the from_str.
       from_str = '\n'.join('  ' + l for l in from_str.split('\n'))
@@ -447,7 +447,21 @@ class RuleStructure(object):
         ordered_distinct_vars = [
             v for v in self.select.keys() if v in self.distinct_vars]
         r += '\nGROUP BY '
-        r += ', '.join(map(LogicaFieldToSqlField, ordered_distinct_vars))
+        if subquery_encoder.execution.dialect.GroupBySpecBy() == 'name':
+          r += ', '.join(map(LogicaFieldToSqlField, ordered_distinct_vars))
+        elif subquery_encoder.execution.dialect.GroupBySpecBy() == 'index':
+          selected_fields = list(self.select.keys())
+          r += ', '.join(str(selected_fields.index(v) + 1)
+                         for v in ordered_distinct_vars)
+        elif subquery_encoder.execution.dialect.GroupBySpecBy() == 'expr':
+          r += ', '.join(
+            ql.ConvertToSql(self.select[k]) for k in ordered_distinct_vars
+          )
+        else:
+          assert False, 'Broken dialect %s, group by spec: %s' % (
+              subquery_encoder.execution.dialect.Name(),
+              subquery_encoder.execution.dialect.GroupBySpecBy())
+
     return r
 
 
@@ -511,9 +525,21 @@ def ExtractInclusionStructure(inclusion, s):
   s.vars_unification.append({
       'left': inclusion['element'],
       'right': {
-          'variable': {
-              'var_name': var_name
+        'call': {
+          'predicate_name': 'ValueOfUnnested',
+          'record': {
+            'field_value': [{
+              'field': 0,
+              'value': {
+                'expression': {
+                  'variable': {
+                    'var_name': var_name
+                  }
+                }
+              }
+            }]
           }
+        }
       }
   })
 
